@@ -3,9 +3,8 @@ import os
 
 class MappingRoutesGenerator:
 
-    def generate(self):
-            current_dir = os.path.normpath(os.path.dirname(__file__))
-            language_files = os.scandir(os.path.join(current_dir, 'languageFiles/en-US')) # 'en-US' is a standard language file for this generator 
+    def generate(self, language_file_path):
+            language_files = os.scandir(os.path.join(language_file_path, 'languageFiles/en-US')) # 'en-US' is a standard language file for this generator 
             parse_route_record = []
             i18n_json_routes_map = {} # Use this dict dump to json file
 
